@@ -12,6 +12,11 @@ import time as myTime
 import sys
 import gobject
 
+#import gtk stuff for dialogs
+import pygtk
+import gtk
+import hildon
+
 import ci_init as ci
 import ci_eventsNew as ci_events
 import ci_flip
@@ -21,7 +26,8 @@ import ci_config
 
 from pygame import *
 
-
+#tracker for hold reset
+defaultDownTime = 0
 
 ###############################################################################
 # clockEventIdle 
@@ -36,6 +42,8 @@ from pygame import *
 # NO CLOCK/TIME events here, just pygame interactivity events
 ###############################################################################
 def clockEventIdle():
+	global defaultDownTime
+	
 	#nothing else going on, so check for pygame events?...
 	event = ci.pygame.event.poll();
 			
@@ -79,7 +87,27 @@ def clockEventIdle():
 			else:
 				#Now out of insomniac mode
 				note.system_note_infoprint("Insomniac mode off...")
-			
+
+
+##### Not needed, taken care of by command line options...
+#		elif (event.key == 285):
+#			currTime = myTime.time()
+#			if (currTime - defaultDownTime > 5):
+#				#print "Default requested!"
+#				dialog = hildon.Note("confirmation", (hildon.Window(), "Really force-clear all FlipClock Alarms from system?", gtk.STOCK_DIALOG_WARNING))
+#				dialog.set_button_texts("Yes", "No")
+#				resp = dialog.run()
+#				dialog.destroy()
+#				
+#				if (resp == gtk.RESPONSE_OK):
+#					print "Reset demanded"
+#				
+#				
+#	elif event.type == KEYDOWN:
+#		#Menu Key is pressed
+#		if (event.key == 285):
+#			defaultDownTime = myTime.time()
+		
 	
 	if (ci.inactive == 0 or ci.charging == 1):
 		myTime.sleep(0.01)
