@@ -17,7 +17,7 @@ import calendar
 import ci_gfx
 import ci_clock
 import ci_alarmNew as ci_alarm
-import ci_clock
+
 
 #Load the configuration/preferences module
 import ci_config
@@ -693,34 +693,42 @@ clockScreenButtons["snooze"].setEnableCondition("ci.alarmRunning", 1)
 clockScreenLabels = {}
 
 #Alarm Time Label (alarm off)
-clockScreenLabels["alarmTime"] = ci_labels.textLabel(Rect(87, 400, 114, 55), "", "ci_config.alarms[ci.thisDay][\"alarm_hhmm\"][0:2] + \":\" + ci_config.alarms[ci.thisDay][\"alarm_hhmm\"][2:4]")
-clockScreenLabels["alarmTime"].setColour((110, 110, 110))
-clockScreenLabels["alarmTime"].setEnableCondition("ci_config.alarms[ci.thisDay][\"enabled\"]", 0)
+#clockScreenLabels["alarmTime"] = ci_labels.textLabel(Rect(87, 400, 114, 55), "", "ci_alarm.getNextAlarmTimeString()")
+#clockScreenLabels["alarmTime"].setColour((110, 110, 110))
+#clockScreenLabels["alarmTime"].setEnableCondition("ci_alarm.hasNextAlarm()", 1)
 
 ##Alarm time label (alarmOn)
-clockScreenLabels["alarmTimeOn"] = ci_labels.textLabel(Rect(87, 400, 114, 55), "", "ci_config.alarms[ci.thisDay][\"alarm_hhmm\"][0:2] + \":\" + ci_config.alarms[ci.thisDay][\"alarm_hhmm\"][2:4]")
+clockScreenLabels["alarmTimeOn"] = ci_labels.textLabel(Rect(87, 400, 114, 55), "", "ci_alarm.getNextAlarmTimeString()")
 clockScreenLabels["alarmTimeOn"].setColour((ci.mr, ci.mg, ci.mb))
-clockScreenLabels["alarmTimeOn"].setEnableCondition("ci_config.alarms[ci.thisDay][\"enabled\"]", 1)
+clockScreenLabels["alarmTimeOn"].setEnableCondition("ci_alarm.hasNextAlarm()", 1)
 
 ##Alarm on helpers
-clockScreenLabels["alarmEngaged"] = ci_labels.textLabel(Rect(114, 389, 114, 55), "ALARM")
+clockScreenLabels["alarmEngaged"] = ci_labels.textLabel(Rect(114, 389, 114, 55), "", "ci_alarm.getNextAlarmDayString()")
 clockScreenLabels["alarmEngaged"].setColour((ci.mr, ci.mg, ci.mb))
 clockScreenLabels["alarmEngaged"].setFont(ci.flipFonts["small"])
-clockScreenLabels["alarmEngaged"].setEnableCondition("ci_config.alarms[ci.thisDay][\"enabled\"]", 1)
+clockScreenLabels["alarmEngaged"].setEnableCondition("ci_alarm.hasNextAlarm()", 1)
 
 clockScreenLabels["alarmEngaged2"] = ci_labels.textLabel(Rect(104, 443, 114, 55), "ENGAGED")
 clockScreenLabels["alarmEngaged2"].setColour((ci.mr, ci.mg, ci.mb))
 clockScreenLabels["alarmEngaged2"].setFont(ci.flipFonts["small"])
-clockScreenLabels["alarmEngaged2"].setEnableCondition("ci_config.alarms[ci.thisDay][\"enabled\"]", 1)
+clockScreenLabels["alarmEngaged2"].setEnableCondition("ci_alarm.hasNextAlarm()", 1)
+
+##Alarm countdown
+clockScreenLabels["alarmCountdown"] = ci_labels.textLabel(Rect(233,402, 55, 114), "", "ci_alarm.getCountdown()")
+clockScreenLabels["alarmCountdown"].setAngle(90)
+clockScreenLabels["alarmCountdown"].setFont(ci.flipFonts["small"])
+clockScreenLabels["alarmCountdown"].setColour((ci.mr, ci.mg, ci.mb))
+clockScreenLabels["alarmCountdown"].setEnableCondition("ci_alarm.hasNextAlarm()", 1)
+
 
 ##Date Labels
 clockScreenLabels["dateLabel1"] = ci_labels.textLabel(Rect(293,395, 114, 55), "", "ci.time.strftime(\"%b - %Y\")")
-clockScreenLabels["dateLabel1"].setColour((55,55,55))
+clockScreenLabels["dateLabel1"].setColour((ci.mr, ci.mg, ci.mb))
 clockScreenLabels["dateLabel1"].setFont(ci.flipFonts["small"])
 clockScreenLabels["dateLabel1"].setEnableCondition("ci.alarmRunning", 0)
 
 clockScreenLabels["dateLabel2"] = ci_labels.textLabel(Rect(291,417, 220, 80), "", "ci.time.strftime(\"%a %d\")")
-clockScreenLabels["dateLabel2"].setColour((55,55,55))
+clockScreenLabels["dateLabel2"].setColour((ci.mr, ci.mg, ci.mb))
 clockScreenLabels["dateLabel2"].setEnableCondition("ci.alarmRunning", 0)
 
 
@@ -774,34 +782,41 @@ clockScreenLabels["snoozeText2"].setEnableCondition("ci.alarmRunning", 1)
 clockNightScreenLabels = {}
 
 #Alarm Time Label (alarm off)
-clockNightScreenLabels["alarmTime"] = ci_labels.textLabel(Rect(87, 400, 114, 55), "", "ci_config.alarms[ci.thisDay][\"alarm_hhmm\"][0:2] + \":\" + ci_config.alarms[ci.thisDay][\"alarm_hhmm\"][2:4]")
-clockNightScreenLabels["alarmTime"].setColour((110, 110, 110))
-clockNightScreenLabels["alarmTime"].setEnableCondition("ci_config.alarms[ci.thisDay][\"enabled\"]", 0)
+#clockNightScreenLabels["alarmTime"] = ci_labels.textLabel(Rect(87, 400, 114, 55), "", "ci_alarm.getNextAlarmTimeString()")
+#clockNightScreenLabels["alarmTime"].setColour((110, 110, 110))
+#clockNightScreenLabels["alarmTime"].setEnableCondition("ci_alarm.hasNextAlarm()", 1)
 
 ##Alarm time label (alarmOn)
-clockNightScreenLabels["alarmTimeOn"] = ci_labels.textLabel(Rect(87, 400, 114, 55), "", "ci_config.alarms[ci.thisDay][\"alarm_hhmm\"][0:2] + \":\" + ci_config.alarms[ci.thisDay][\"alarm_hhmm\"][2:4]")
+clockNightScreenLabels["alarmTimeOn"] = ci_labels.textLabel(Rect(87, 400, 114, 55), "", "ci_alarm.getNextAlarmTimeString()")
 clockNightScreenLabels["alarmTimeOn"].setColour((ci.mr, ci.mg, ci.mb))
-clockNightScreenLabels["alarmTimeOn"].setEnableCondition("ci_config.alarms[ci.thisDay][\"enabled\"]", 1)
+clockNightScreenLabels["alarmTimeOn"].setEnableCondition("ci_alarm.hasNextAlarm()", 1)
 
 ##Alarm on helpers
-clockNightScreenLabels["alarmEngaged"] = ci_labels.textLabel(Rect(114, 389, 114, 55), "ALARM")
+clockNightScreenLabels["alarmEngaged"] = ci_labels.textLabel(Rect(114, 389, 114, 55), "", "ci_alarm.getNextAlarmDayString()")
 clockNightScreenLabels["alarmEngaged"].setColour((ci.mr, ci.mg, ci.mb))
 clockNightScreenLabels["alarmEngaged"].setFont(ci.flipFonts["small"])
-clockNightScreenLabels["alarmEngaged"].setEnableCondition("ci_config.alarms[ci.thisDay][\"enabled\"]", 1)
+clockNightScreenLabels["alarmEngaged"].setEnableCondition("ci_alarm.hasNextAlarm()", 1)
 
 clockNightScreenLabels["alarmEngaged2"] = ci_labels.textLabel(Rect(104, 443, 114, 55), "ENGAGED")
 clockNightScreenLabels["alarmEngaged2"].setColour((ci.mr, ci.mg, ci.mb))
 clockNightScreenLabels["alarmEngaged2"].setFont(ci.flipFonts["small"])
-clockNightScreenLabels["alarmEngaged2"].setEnableCondition("ci_config.alarms[ci.thisDay][\"enabled\"]", 1)
+clockNightScreenLabels["alarmEngaged2"].setEnableCondition("ci_alarm.hasNextAlarm()", 1)
+
+##Alarm countdown
+clockNightScreenLabels["alarmCountdown"] = ci_labels.textLabel(Rect(233,402, 55, 114), "", "ci_alarm.getCountdown()")
+clockNightScreenLabels["alarmCountdown"].setAngle(90)
+clockNightScreenLabels["alarmCountdown"].setFont(ci.flipFonts["small"])
+clockNightScreenLabels["alarmCountdown"].setColour((ci.mr, ci.mg, ci.mb))
+clockNightScreenLabels["alarmCountdown"].setEnableCondition("ci_alarm.hasNextAlarm()", 1)
 
 ##Date Labels
 clockNightScreenLabels["dateLabel1"] = ci_labels.textLabel(Rect(293,395, 114, 55), "", "ci.time.strftime(\"%b - %Y\")")
-clockNightScreenLabels["dateLabel1"].setColour((55,55,55))
+clockNightScreenLabels["dateLabel1"].setColour((ci.mr, ci.mg, ci.mb))
 clockNightScreenLabels["dateLabel1"].setFont(ci.flipFonts["small"])
 clockNightScreenLabels["dateLabel1"].setEnableCondition("ci.alarmRunning", 0)
 
 clockNightScreenLabels["dateLabel2"] = ci_labels.textLabel(Rect(291,417, 220, 80), "", "ci.time.strftime(\"%a %d\")")
-clockNightScreenLabels["dateLabel2"].setColour((55,55,55))
+clockNightScreenLabels["dateLabel2"].setColour((ci.mr, ci.mg, ci.mb))
 clockNightScreenLabels["dateLabel2"].setEnableCondition("ci.alarmRunning", 0)
 
 #### Alarm is playing labels ##########
