@@ -7,13 +7,16 @@ import ConfigParser
 
 from datetime import date
 
+#Option parser for CLI options
+from optparse import OptionParser
+
 import dbus
 import gobject
 
 import osso
 from dbus.mainloop.glib import DBusGMainLoop
 ######################################################################
-# Flipclock 0.2.0 Inizializzazione variabili generiche
+# Flipclock 0.2.1 Inizializzazione variabili generiche
 # Ciro Ippolito ciron810@gmail.com
 # Updated by Rob Williams (jolouis) for dbus handling
 #  20.00 - 04/03/2009
@@ -32,6 +35,25 @@ else:
 	path="../../../../share/flipclock/"       #sloppy local ./data/ path
 	userpath="../../../../share/flipclock/"
 
+
+######################## Command Line Options ########################
+#
+######################################################################
+usage = "usage: %prog [options] arg"
+cliParser = OptionParser(usage=usage, version="0.2.1", prog="FlipClock")
+
+cliParser.set_defaults(fixAlarms=False)
+cliParser.add_option("-f", "--fix-alarms", action="store_true", dest="fixAlarms", help="Scan and attempt to clear any erronious Flipclock alarms.")
+
+
+(cliOptions, cliArgs) = cliParser.parse_args()
+
+
+
+
+######################## Done Command Line Options ###################
+
+
 ######################## Added by Rob 02/27/09 #######################
 # Dbus initialization/handling 
 ######################################################################
@@ -74,7 +96,7 @@ remaing  =[0,0,0,0]             #Countdown variable
 
 
 pygame.init()
-pygame.display.set_caption('Flip Clock 0.2.0 BETA')
+pygame.display.set_caption('Flip Clock 0.2.1 BETA')
 if tablet==1:
   screenSize = pygame.Rect(0,0,800,480)
 
